@@ -40,7 +40,7 @@ mod2 <-
     
   )
 
-res2 <- run_model(
+res2 <- run_models(
   mod1, mod2,
   init = 1:0,
   cycles = 10,
